JWPlayerPlatform class abstract

Inheritance
  • Object
  • PlatformInterface
  • JWPlayerPlatform
Implementers

Constructors

JWPlayerPlatform()
Constructs a FlutterPocPlatform.

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

buildView(int viewId, void onPlatformViewCreated(int)) → Widget
create() → Future<int>
dispose(int viewId) → Future<void>
getPlatformVersion() → Future<String?>
init() → Future<void>
Initializes the platform interface and disposes all existing players.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
pause(int id) → Future<void>
play(int id) → Future<void>
seek(double to, int id) → Future<void>
setConfig(Map<String, dynamic> config, int id) → Future<void>
setLicenseKey(String licenseKey) → Future<void>
stop(int id) → Future<void>
toString() → String
A string representation of this object.
inherited
videoEventsFor(int textureId) → Stream<VideoEvent>
Returns a Stream of VideoEventTypes.

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

instance ↔ JWPlayerPlatform
The default instance of FlutterPocPlatform to use.
getter/setter pair