VideoEvent class

Annotations

Constructors

VideoEvent({required VideoEventType eventType, Duration? duration, Duration position = Duration.zero, Size? size, double? bufferPercent = 0, double? bufferPosition = 0, PlayerState state = PlayerState.idle})
Creates an instance of VideoEvent.

Properties

bufferPercent → double?
final
bufferPosition → double?
final
duration → Duration?
Duration of the video.
final
eventType → VideoEventType
The type of the event.
final
hashCode → int
The hash code for this object.
no setteroverride
position → Duration
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
size → Size?
Size of the video.
final
state → PlayerState
Player state
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
override