JWVideoPlayerValue class

The duration, current position, error state and settings of a JWPlayerController.

Constructors

JWVideoPlayerValue({JWPlayerConfiguration? config, Duration duration = Duration.zero, Size size = Size.zero, bool isPlaying = false, Duration position = Duration.zero, bool isInitialized = false, double bufferPercentage = 0.0, double bufferPosition = 0.0, String? errorDescription, PlayerState state = PlayerState.idle})
Constructs a video with the given values.
JWVideoPlayerValue.erroneous(String errorDescription)
Returns an instance with the given errorDescription.
JWVideoPlayerValue.uninitialized()
Returns an instance for a video that hasn't been loaded.

Properties

aspectRatio → double
Returns size.width / size.height.
no setter
bufferPercentage → double
Indicates the percentage the content has buffer
final
bufferPosition → double
Indicates the current position for the buffer regarding the duration
final
config ↔ JWPlayerConfiguration?
getter/setter pair
duration → Duration
The total duration of the video.
final
errorDescription → String?
A description of the error if present.
final
hasError → bool
Indicates whether or not the video is in an error state. If this is true errorDescription should have information about the problem.
no setter
hashCode → int
The hash code for this object.
no setterinherited
isInitialized → bool
Indicates whether or not the video has been loaded and is ready to play.
final
isPlaying → bool
True if the video is playing. False if it's paused.
final
position → Duration
The current playback position.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
size → Size
The size of the currently loaded video.
final
state → PlayerState
Indicates the current state of the player.
final

Methods

copyWith({Duration? duration, Size? size, Duration? position, bool? isInitialized, String? errorDescription, double? bufferPercentage, double? bufferPosition, PlayerState? state}) → JWVideoPlayerValue
Returns a new instance that has the same values as this current instance, except for any overrides passed in as arguments to copyWith.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited